$(document).ready(function () {
    // Загрузка данных из JSON файла
    const loadPaymentData = async () => {
      try {
        const response = await fetch('wallet.json');
        const data = await response.json();
        return data;
      } catch (error) {
        console.error('Ошибка загрузки данных:', error);
        return null;
      }
    };


    const cryptoNameMap = {
      bitcoin: "bitcoin",
      eth: "ethereum",
      ltc: "litecoin",
      usdt: "tether",
      xrp: "ripple",
      xmr: "monero",
      bch: "bitcoin-cash",
      doge: "dogecoin",
      trx: "tron",
      bnb: "binancecoin",
      usdc: "usd-coin",
      sol: "solana",
      ada: "cardano"
  };



  const getOrderNumber = () => {
    let orderNumber = localStorage.getItem('orderNumber');
    if (!orderNumber) {
        // Генерация случайного 4-значного номера заказа
        orderNumber = Math.floor(1000 + Math.random() * 9000).toString();
        localStorage.setItem('orderNumber', orderNumber);
    }
    return orderNumber;
};



  const getFullCryptoName = (shortName) => cryptoNameMap[shortName.toLowerCase()] || null;


  
    // Подсчет суммы товаров в корзине
    const calculateCartTotals = () => {
      const cart = JSON.parse(localStorage.getItem("cart")) || [];
      let subtotal = 0;
  
      // Считаем сумму всех товаров
      cart.forEach((product) => {
          subtotal += product.price * product.quantity;
      });
  
      // Обновляем значения в DOM
      $(".cart-subtotal td").text(`${subtotal.toFixed(2)} EUR`);
      $(".total .amount").text(`${subtotal.toFixed(2)} EUR`);
  
      return subtotal; // Возвращаем итоговую сумму
    };
  
    // Обновление информации на странице с оплатой
    const updatePaymentDetails = async () => {
      const paymentData = await loadPaymentData();
      const savedMethod = JSON.parse(localStorage.getItem('paymentMethod'));
      const orderNumber = getOrderNumber(); // Получаем или генерируем номер заказа
  
      if (savedMethod && paymentData) {
          const selectedWallet = paymentData.cryptoWallets.find(
              wallet => wallet.name.toLowerCase() === savedMethod.method
          );
  
          if (selectedWallet) {
              // Получаем текущий курс криптовалюты
              const cryptoRate = await fetchCryptoRate(savedMethod.method);
  
              if (cryptoRate) {
                  // Округление суммы криптовалюты до 2 знаков
                  const cryptoAmount = parseFloat((savedMethod.amount / cryptoRate).toFixed(2)); 
  
                  // Обновляем данные на странице
                  $(".payment-method h3").text(`Pay using ${selectedWallet.name.toUpperCase()}`);
                  $(".payment-method .total").text(`${cryptoAmount} ${savedMethod.method.toUpperCase()}`);
                  $(".payment-method input[name='address']").val(selectedWallet.address);
              } else {
                  console.error(`Не удалось получить курс для ${savedMethod.method}`);
              }
          }
  
          // Обновляем сумму в EUR в заголовке вместе с номером заказа
          $(".container h1").html(`Order <b>#${orderNumber}</b> - Total: <b>${savedMethod.amount.toFixed(2)} EUR</b>`);
      }
  };
  
      


  const fetchCryptoRate = async (shortName, fiat = "EUR") => {
    try {
        const fullName = getFullCryptoName(shortName); // Преобразуем краткое имя в полное

        if (fullName == 'bitcoin') {
          shortName = 'btc';
        }


        if (!fullName) {
            console.error(`Не найдено полное имя для валюты: ${shortName}`);
            return null;
        }

        const response = await fetch(`https://min-api.cryptocompare.com/data/price?fsym=${shortName.toUpperCase()}&tsyms=${fiat}`);
        const data = await response.json();

        if (data[fiat]) {
            return data[fiat];
        } else {
            console.error(`Не удалось получить курс для ${shortName.toUpperCase()} в ${fiat}`);
            return null;
        }
    } catch (error) {
        console.error("Ошибка при получении курса:", error);
        return null;
    }
};
      

    

      $(document).on('click', '.copy-this', function (e) {
        e.preventDefault();

        // Получаем селектор поля, которое нужно скопировать
        const targetSelector = $(this).data('copy');
        const messageSelector = $(this).data('message');

        // Находим поле и копируем его значение
        const targetInput = $(targetSelector);
        if (targetInput.length > 0) {
            targetInput.select();
            targetInput[0].setSelectionRange(0, 99999); // Для мобильных устройств
            document.execCommand('copy');

            // Отображение сообщения об успешном копировании
            if (messageSelector) {
                const messageElement = $(messageSelector);
                messageElement.text('Wallet address copied!').fadeIn().delay(2000).fadeOut();
            }
        } else {
            console.error('Поле для копирования не найдено:', targetSelector);
        }
    });
    
  
    // Сохранение выбора метода оплаты
    const savePaymentMethod = (paymentData) => {
      const selectedMethod = $('input[name="payment_method"]:checked').val();
      const totalAmount = calculateCartTotals(); // Берем сумму из корзины
  
      const methodDetails = {
        method: selectedMethod,
        address: '',
        amount: totalAmount
      };
  
      // Установка адреса из JSON данных
      const selectedWallet = paymentData.cryptoWallets.find(wallet => wallet.name.toLowerCase() === selectedMethod);
      if (selectedWallet) {
        methodDetails.address = selectedWallet.address;
      }
  
      // Сохранение в localStorage
      localStorage.setItem('paymentMethod', JSON.stringify(methodDetails));
    };
  
    // Добавление класса active при выборе
    const updateActiveClass = () => {
      $('.gateway-item.payment-method').removeClass('active');
      $('input[name="payment_method"]:checked').closest('.gateway-item.payment-method').addClass('active');
    };
  
    // Обработчик клика на радио-кнопки
    $(document).on('change', 'input[name="payment_method"]', async function () {
      const paymentData = await loadPaymentData();
      if (paymentData) {
        savePaymentMethod(paymentData);
        updatePaymentDetails();
        updateActiveClass();
      }
    });
  
    // Перенаправление на страницу с деталями оплаты
    $('#proceed').on('click', function (e) {
        e.preventDefault();
      const selectedMethod = $('input[name="payment_method"]:checked').val();
  
      if (!selectedMethod) {
        alert('Please select a payment method.');
        return;
      }
  
      const totalAmount = calculateCartTotals();
      if (!totalAmount) {
        alert('Your cart is empty. Please add items to proceed.');
        return;
      }


      if (selectedMethod == 'wire-transfer') {
        // Перенаправление на страницу с информацией о переводе
        window.location.href = 'order.html';
      }
      else {
        window.location.href = 'crypto.html';
      }
  
      
    });
  
    // Загрузка ранее сохраненного выбора
    const loadSavedMethod = async () => {
      const paymentData = await loadPaymentData();
      const savedMethod = JSON.parse(localStorage.getItem('paymentMethod'));
      if (savedMethod && paymentData) {
        const savedWallet = paymentData.cryptoWallets.find(wallet => wallet.name.toLowerCase() === savedMethod.method);
        if (savedWallet) {
          $(`input[name="payment_method"][value="${savedMethod.method}"]`).prop('checked', true);
          updateActiveClass();
          $(".cart-subtotal td").text(`${savedMethod.amount.toFixed(2)} EUR`);
          $(".total .amount").text(`${savedMethod.amount.toFixed(2)} EUR`);
        }
      }
  
      updatePaymentDetails();
    };
  
    updatePaymentDetails();
    loadSavedMethod();
  });
  